==> sugarcrm-2.5.1b_1.tbz: www/sugarcrm/modules/DynamicLayout/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version
 * 1.1.3 ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * All copies of the Covered Code must include on each user interface screen:
 *    (i) the "Powered by SugarCRM" logo and
 *    (ii) the SugarCRM copyright notice
 * in the same form as they appear in the distribution.  See full license for
 * requirements.
 *
 * The Original Code is: SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) 2004 SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/

$mod_strings = array (
'LBL_ADVANCED'=> 'Advanced:',
'DESC_USING_LAYOUT_TITLE' => 'Using the Layout Editor',
'DESC_USING_LAYOUT_SHORTCUTS' => 'Shortcuts:',
'DESC_USING_LAYOUT_TOOLBAR' => 'Toolbar:',
'DESC_USING_LAYOUT_EDIT_ROWS' => 'Edit Rows:',
'DESC_USING_LAYOUT_SELECT_FILE' => 'Select File:',
'DESC_USING_LAYOUT_EDIT_FIELDS' => 'Edit Fields:',
'DESC_USING_LAYOUT_ADD_FIELD' => 'Add Field:',
'DESC_USING_LAYOUT_REMOVE_ITEM' => 'Remove an item:',
'DESC_USING_LAYOUT_DISPLAY_HTML' => 'Display HTML code:',
'DESC_USING_LAYOUT_BLK1' => 'The Layout editor lets you rearrange fields, tabs, and panels on tabs to customize screens to fit your needs. First select the view of the page you want to customize via the Select File shortcut.',
'DESC_USING_LAYOUT_BLK2' => ' allows you to select a different page to edit; edits on the current page are lost if not saved. If youre not sure what file to edit you can check the Edit in place box; this will add an edit box to all the editable places through the application. Navigate through the application to the page you want to edit, click on the edit box, and you will be returned to the edit display for that file.',
'DESC_USING_LAYOUT_BLK3' => ' drag and rearrange individual fields or their labels. Select the item handle ',
'DESC_USING_LAYOUT_BLK4' => ' next to the field or label you want to move, and click on the item handle where you want the field or label located. This will move the item from its previous location to its new location. If there was already a field or label at the destination the two items will swap positions. Moving sub-panels is the same as moving fields; select on the source sub-panel handle and destination handle and the two will switch locations. To remove a field or form from the screen, drag the item to the Toolbox area in the left menu bar.',
'DESC_USING_LAYOUT_BLK5' => ' changes the view to allow the addition and removal of rows in the details panel. Pressing the + adds a row below the one selected, and pressing the  removes that row.',
'DESC_USING_LAYOUT_BLK6' => 'The Toolbox provides a workspace to add new fields and labels to a form, temporarily retain items that have been removed from a form, and discard items.',
'DESC_USING_LAYOUT_BLK7' => ' opens a selection display to specify the type of field you want to add and the label that goes with it. Pressing the Add button puts the new field and its label in the Toolbox workspace. From here the field can be added by selecting the new items handle and the handle for its destination.',
'DESC_USING_LAYOUT_BLK8' => ' is accomplished by selecting its handle and clicking on the text Drag unwanted items here. This will deposit the selected item in the Toolbox workspace.',
'DESC_USING_LAYOUT_BLK9' => ' selection field displays the html that comprises each field. While this can be informative it is very CPU intensive, and should only be used when necessary.',
'DESC_USING_LAYOUT_BLK10' => 'To save changes press the Save Layout button. To discard changes click on another tab in the application and all changes will be discarded for the page being edited.',
'NO_RECORDS_LISTVIEW'=>'In order to edit a list view there must be at least one row of data.  Please create a record for this list view before attempting to edit.',
);
?>

==> sugarcrm-3.5.1.tbz: www/sugarcrm/modules/DynamicLayout/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version
 * 1.1.3 ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * All copies of the Covered Code must include on each user interface screen:
 *    (i) the "Powered by SugarCRM" logo and
 *    (ii) the SugarCRM copyright notice
 * in the same form as they appear in the distribution.  See full license for
 * requirements.
 *
 * The Original Code is: SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) 2004-2005 SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/

$mod_strings = array (
'LBL_ADVANCED'=> 'Advanced:',
'DESC_USING_LAYOUT_TITLE' => 'Using the Layout Editor',
'DESC_USING_LAYOUT_SHORTCUTS' => 'Shortcuts:',
'DESC_USING_LAYOUT_TOOLBAR' => 'Toolbar:',
'DESC_USING_LAYOUT_EDIT_ROWS' => 'Edit Rows:',
'DESC_USING_LAYOUT_SELECT_FILE' => 'Select File:',
'DESC_USING_LAYOUT_EDIT_FIELDS' => 'Edit Layout:',
'DESC_USING_LAYOUT_ADD_FIELD' => 'Add Field:',
'DESC_USING_LAYOUT_REMOVE_ITEM' => 'Remove an item:',
'DESC_USING_LAYOUT_DISPLAY_HTML' => 'Display HTML code:',
'DESC_USING_LAYOUT_BLK1' => 'The Layout editor lets you rearrange fields, tabs, and panels on tabs to customize screens to fit your needs. First select the view of the page you want to customize via the Select File shortcut.',
'DESC_USING_LAYOUT_BLK2' => ' allows you to select a different page to edit; edits on the current page are lost if not saved. If youre not sure what file to edit you can check the Edit in place box; this will add an edit box to all the editable places through the application. Navigate through the application to the page you want to edit, click on the edit box, and you will be returned to the edit display for that file.',
'DESC_USING_LAYOUT_BLK3' => ' drag and rearrange individual fields or their labels. Select the item handle ',
'DESC_USING_LAYOUT_BLK4' => ' next to the field or label you want to move, and click on the item handle where you want the field or label located. This will move the item from its previous location to its new location. If there was already a field or label at the destination the two items will swap positions. Moving sub-panels is the same as moving fields; select on the source sub-panel handle and destination handle and the two will switch locations. To remove a field or form from the screen, drag the item to the Toolbox area in the left menu bar.',
'DESC_USING_LAYOUT_BLK5' => ' changes the view to allow the addition and removal of rows in the details panel. Pressing the + adds a row below the one selected, and pressing the  removes that row.',
'DESC_USING_LAYOUT_BLK6' => 'The Toolbox provides a workspace to add new fields and labels to a form, temporarily retain items that have been removed from a form, and discard items.',
'DESC_USING_LAYOUT_BLK7' => ' opens a selection display to specify the type of field you want to add and the label that goes with it. Pressing the Add button puts the new field and its label in the Toolbox workspace. From here the field can be added by selecting the new items handle and the handle for its destination.',
'DESC_USING_LAYOUT_BLK8' => ' is accomplished by selecting its handle and clicking on the text Drag unwanted items here. This will deposit the selected item in the Toolbox workspace.',
'DESC_USING_LAYOUT_BLK9' => ' selection field displays the html that comprises each field. While this can be informative it is very CPU intensive, and should only be used when necessary.',
'DESC_USING_LAYOUT_BLK10' => 'To save changes press the Save Layout button. To discard changes click on another tab in the application and all changes will be discarded for the page being edited.',
'NO_RECORDS_LISTVIEW'=>'In order to edit a list view there must be at least one row of data.  Please create a record for this list view before attempting to edit.',
'LBL_EDIT_LAYOUT'=>'Edit Layout',
'LBL_EDIT_ROWS'=>'Edit Rows',
'LBL_EDIT_COLUMNS'=>'Edit Columns',
'LBL_EDIT_LABELS'=>'Edit Labels',
'LBL_EDIT_FIELDS'=>'Edit Custom Fields',
'LBL_ADD_FIELDS'=>'Add Custom Fields',
'LBL_DISPLAY_HTML'=>'Display HTML Code',
'LBL_SELECT_FILE'=> 'Select File',
);
?>
